---
title: llarp::layers::platform::PlatformDriver_Base
summary: base type that is responsible for bridging the os and the flow layer. 

---

# llarp::layers::platform::PlatformDriver_Base



base type that is responsible for bridging the os and the flow layer.  [More...](#detailed-description)


`#include <driver_base.hpp>`

## Public Functions

|                | Name           |
| -------------- | -------------- |
| | **[PlatformDriver_Base](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-platformdriver-base)**([PlatformLayer_Base](Classes/classllarp_1_1layers_1_1platform_1_1PlatformLayer__Base.md) & ) |
| virtual | **[~PlatformDriver_Base](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-~platformdriver-base)**() =default |
| constexpr void | **[wakeup_os](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-wakeup-os)**() const<br>wake up lokinet event loop telling it we sent some things to the network.  |
| constexpr void | **[wakeup_flow_layer](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-wakeup-flow-layer)**() const<br>wake up the flow layer. tell it we sent it some things and should process it.  |
| void | **[attach_to_loop](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-attach-to-loop)**([EventLoop](Classes/classllarp_1_1EventLoop.md) & loop)<br>attach ourself to the event loop.  |
| template <typename FlowCompare_t \> <br>std::map< [flow::FlowInfo](Classes/structllarp_1_1layers_1_1flow_1_1FlowInfo.md), [PlatformAddr](Classes/structllarp_1_1layers_1_1platform_1_1PlatformAddr.md), FlowCompare_t > | **[get_address_mappings_for](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-get-address-mappings-for)**([flow::FlowAddr](Classes/classllarp_1_1layers_1_1flow_1_1FlowAddr.md) remote, net::flowlabel_t flow_label ={0})<br>get all flows to a remote.  |
| std::unique_ptr< [NameResolverJob_Base](Classes/classllarp_1_1layers_1_1platform_1_1NameResolverJob__Base.md) > | **[make_resolver_job_for](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-make-resolver-job-for)**(UnresolvedName_t name) const<br>given a name we want to look up, make a one shot job that we will use to look it up from the network.  |

## Protected Functions

|                | Name           |
| -------------- | -------------- |
| void | **[before_loop_ready](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-before-loop-ready)**()<br>called once per event loop tick, before polling for io.  |
| virtual bool | **[loop_ready](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-loop-ready)**()<br>called once per event loop tick after platform layer event loop is ready to be read.  |
| virtual void | **[after_loop_ready](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-after-loop-ready)**()<br>called once per event loop after we have processed all our events from a read cycle.  |
| virtual std::unique_ptr< [NameResolverJob_Base](Classes/classllarp_1_1layers_1_1platform_1_1NameResolverJob__Base.md) > | **[make_resolver_job_for](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-make-resolver-job-for)**(UnresolvedName_t name) const<br>given a name we want to look up, make a one shot job that we will use to look it up from the network.  |

## Protected Attributes

|                | Name           |
| -------------- | -------------- |
| [OSTraffic_IO](Classes/classllarp_1_1layers_1_1platform_1_1OSTraffic__IO.md) | **[m_os_io](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#variable-m-os-io)**  |
| [FlowTraffic_IO](Classes/classllarp_1_1layers_1_1platform_1_1FlowTraffic__IO.md) | **[m_flow_io](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#variable-m-flow-io)**  |

## Detailed Description

```cpp
class llarp::layers::platform::PlatformDriver_Base;
```

base type that is responsible for bridging the os and the flow layer. 

each kind of ethertype has its own implementation. 

## Public Functions Documentation

### function PlatformDriver_Base

```cpp
PlatformDriver_Base(
    PlatformLayer_Base & 
)
```


### function ~PlatformDriver_Base

```cpp
virtual ~PlatformDriver_Base() =default
```


### function wakeup_os

```cpp
inline constexpr void wakeup_os() const
```

wake up lokinet event loop telling it we sent some things to the network. 

### function wakeup_flow_layer

```cpp
inline constexpr void wakeup_flow_layer() const
```

wake up the flow layer. tell it we sent it some things and should process it. 

### function attach_to_loop

```cpp
void attach_to_loop(
    EventLoop & loop
)
```

attach ourself to the event loop. 

set up any kind of io we need from it. 


### function get_address_mappings_for

```cpp
template <typename FlowCompare_t >
std::map< flow::FlowInfo, PlatformAddr, FlowCompare_t > get_address_mappings_for(
    flow::FlowAddr remote,
    net::flowlabel_t flow_label ={0}
)
```

get all flows to a remote. 

if flow_label is nonzero we will only fetch mappings for that flow label. sorted in order "best" to "worst". 


### function make_resolver_job_for

```cpp
std::unique_ptr< NameResolverJob_Base > make_resolver_job_for(
    UnresolvedName_t name
) const
```

given a name we want to look up, make a one shot job that we will use to look it up from the network. 

## Protected Functions Documentation

### function before_loop_ready

```cpp
void before_loop_ready()
```

called once per event loop tick, before polling for io. 

### function loop_ready

```cpp
virtual bool loop_ready()
```

called once per event loop tick after platform layer event loop is ready to be read. 

returns true if we proccessed events and thus need to call [after_loop_ready()](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md#function-after-loop-ready). 


### function after_loop_ready

```cpp
virtual void after_loop_ready()
```

called once per event loop after we have processed all our events from a read cycle. 

### function make_resolver_job_for

```cpp
virtual std::unique_ptr< NameResolverJob_Base > make_resolver_job_for(
    UnresolvedName_t name
) const
```

given a name we want to look up, make a one shot job that we will use to look it up from the network. 

## Protected Attributes Documentation

### variable m_os_io

```cpp
OSTraffic_IO m_os_io;
```


### variable m_flow_io

```cpp
FlowTraffic_IO m_flow_io;
```


-------------------------------

Updated on 2023-01-23 at 21:15:39 +0000