---
title: llarp/layers/platform/driver_base.hpp

---

# llarp/layers/platform/driver_base.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::layers](Namespaces/namespacellarp_1_1layers.md)**  |
| **[llarp::layers::platform](Namespaces/namespacellarp_1_1layers_1_1platform.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::layers::platform::OSTraffic_IO](Classes/classllarp_1_1layers_1_1platform_1_1OSTraffic__IO.md)**  |
| class | **[llarp::layers::platform::FlowTraffic_IO](Classes/classllarp_1_1layers_1_1platform_1_1FlowTraffic__IO.md)**  |
| class | **[llarp::layers::platform::PlatformDriver_Base](Classes/classllarp_1_1layers_1_1platform_1_1PlatformDriver__Base.md)** <br>base type that is responsible for bridging the os and the flow layer.  |




## Source code

```cpp
#pragma once

#include "addr_mapper.hpp"
#include "traffic.hpp"

#include <llarp/layers/flow/flow_identity.hpp>
#include <llarp/layers/flow/flow_info.hpp>
#include <llarp/layers/flow/flow_addr.hpp>
#include <llarp/layers/flow/traffic.hpp>

#include <llarp/net/net_int.hpp>
#include <llarp/util/formattable.hpp>
#include <llarp/util/types.hpp>

#include <memory>
#include <optional>
#include <queue>
#include <string_view>
#include <type_traits>
#include <unordered_map>
#include <set>
#include <variant>
#include <vector>

namespace llarp::layers::platform
{

  class OSTraffic_IO
  {
   public:
    virtual std::vector<OSTraffic>
    read_platform_traffic() const;

    virtual void
    write_platform_traffic(std::vector<OSTraffic>&& traff) const;

    virtual void
    wakeup() const;
  };

  class FlowTraffic_IO
  {
   protected:
    flow::FlowLayer_Base& m_flow_layer;

   public:
    virtual void
    write_many_to_flow_layer(
        EtherType_t kind, flow::FlowInfo to, std::vector<std::vector<byte_t>> datums);

    void
    write_to_flow_layer(EtherType_t kind, flow::FlowInfo to, std::vector<byte_t> data)
    {
      write_many_to_flow_layer(
          std::move(kind), std::move(to), std::vector<decltype(data)>{std::move(data)});
    }

    virtual std::vector<flow::Traffic>
    read_from_flow_layer();

    virtual void
    wakeup() const;
  };

  class PlatformDriver_Base
  {
    std::shared_ptr<EventLoopWakeup> m_after_io;

   protected:
    OSTraffic_IO m_os_io;
    FlowTraffic_IO m_flow_io;

    void
    before_loop_ready();

    virtual bool
    loop_ready();

    virtual void
    after_loop_ready();

    virtual std::unique_ptr<NameResolverJob_Base>
    make_resolver_job_for(UnresolvedName_t name) const;

   public:
    PlatformDriver_Base(PlatformLayer_Base&);

    virtual ~PlatformDriver_Base() = default;

    constexpr void
    wakeup_os() const
    {
      m_os_io.wakeup();
    }

    constexpr void
    wakeup_flow_layer() const
    {
      m_flow_io.wakeup();
    }

    // TODO: detach?
    void
    attach_to_loop(EventLoop& loop);

    // TODO: define distance function for "best" and "worst"
    template <typename FlowCompare_t>
    std::map<flow::FlowInfo, PlatformAddr, FlowCompare_t>
    get_address_mappings_for(flow::FlowAddr remote, net::flowlabel_t flow_label = {0});

    std::unique_ptr<NameResolverJob_Base>
    make_resolver_job_for(UnresolvedName_t name) const;
  };
}  // namespace llarp::layers::platform

namespace llarp
{
  template <>
  inline constexpr bool IsToStringFormattable<layers::platform::PlatformAddr> = true;
}
```


-------------------------------

Updated on 2023-01-23 at 21:15:39 +0000
