---
title: llarp/layers/platform/name_resolver.hpp

---

# llarp/layers/platform/name_resolver.hpp



## Namespaces

| Name           |
| -------------- |
| **[llarp](Namespaces/namespacellarp.md)** <br>[crypto.hpp] |
| **[llarp::layers](Namespaces/namespacellarp_1_1layers.md)**  |
| **[llarp::layers::platform](Namespaces/namespacellarp_1_1layers_1_1platform.md)**  |

## Classes

|                | Name           |
| -------------- | -------------- |
| class | **[llarp::layers::platform::NameResolverJob_Base](Classes/classllarp_1_1layers_1_1platform_1_1NameResolverJob__Base.md)** <br>a one shot job that will resolve a string to a resolved name to a platform address.  |




## Source code

```cpp
#pragma once

#include "platform_addr.hpp"

#include <chrono>
#include <optional>

#include <oxenc/variant.h>

#include <llarp/util/types.hpp>
#include <llarp/dns/question.hpp>

namespace llarp::layers::platform
{

  using UnresolvedName_t = std::variant<std::string_view, dns::Question>;

  class NameResolverJob_Base
  {
   protected:
    const TimePoint_t started_at{TimePoint_t::clock::now()};
    const std::string name;
    const Duration_t timeout;

   public:
    template <typename resolution_t, typename rep_t = double>
    NameResolverJob_Base(
        std::string_view name_, std::chrono::duration<rep_t, resolution_t> timeout_)
        : name{name_}, timeout{timeout_} {};

    // handler is passed in here because putting it in the constructor tends to get very messy.
    virtual void
    resolve_async(std::function<void(std::optional<PlatformAddr>)> handler);
  };

}  // namespace llarp::layers::platform
```


-------------------------------

Updated on 2023-01-23 at 21:15:39 +0000
